@@ -664,8 +664,8 @@ int serve_zone(int connect, int perms) {
     switch(*(data->string + 13 + length)) {
         case RR_SOA: /* SOA */
             soa_q = 1;
-        case 251: /* IXFR */
-        case 252: /* AXFR */
+        case RR_IXFR: /* IXFR */
+        case RR_AXFR: /* AXFR */
             break;
         default:
             /* In the case of them having permission to both server
@@ -1142,7 +1142,7 @@ on %s\nFor usage information, type in 'man maradns'" */
 	     * */
 
 	    bind_addresses = libtcp_bind_address(1);
-	    if(bind_addresses[0].ip == 0xffffffff) {
+	    if(bind_addresses == 0 || bind_addresses[0].ip == 0xffffffff) {
 		    harderror("Could not make list of bind addresses");
 	    }
 	    bind_address_iterate = 0;
