@@ -1,4 +1,20 @@
-/* Placed in the public domain 2001 by Sam Trenholme */
+/* Copyright (c) 2002,2003 Sam Trenholme
+ *
+ * TERMS
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * This software is provided 'as is' with no guarantees of correctness or
+ * fitness for purpose.
+ */
 
 /* This is a stub DNS server that converts A record requests in to
    time stamps; used to make sure the various minimum ttls were working
@@ -839,7 +855,7 @@ int main(int argc, char **argv) {
         zjlog(L_BIND2ADDR,bind_address); /* "Binding to address " */
         mlog(L_BIND_SUCCESS);  /* "Socket opened on UDP port 53" */
 
-        /* Drop the elevated privledges */
+        /* Drop the elevated privileges */
         /* First, change the GID */
         if(js_qstr2js(kvar_query,"maradns_gid") == JS_ERROR)
             harderror(L_KVAR_Q); /* "Could not create kvar_query" */
@@ -864,7 +880,7 @@ int main(int argc, char **argv) {
         if(setuid(0) == 0)
             sys_harderror(L_STILL_ROOT);  /* "We seem to still be root" */
 
-        mlog(L_DROP_SUCCESS); /* "Root privledges dropped" */
+        mlog(L_DROP_SUCCESS); /* "Root privileges dropped" */
 
         }
     else {
